@@ -208,13 +208,11 @@ get_caption_hpos <- function (ht) {
 
 make_label <- function (ht) {
   lab <- label(ht)
-  if (is.na(lab) &&
-          getOption("huxtable.autolabel", TRUE) &&
-          requireNamespace("knitr", quietly = TRUE) &&
-          ! is.null(chunk_label <- knitr::opts_current$get("label"))
-        ) {
-
-    if (! is.null(chunk_label)) lab <- paste0("tab:", chunk_label)
+  if (is.na(lab) && getOption("huxtable.autolabel", TRUE) &&
+        requireNamespace("knitr", quietly = TRUE) &&
+        ! is.null(chunk_label <- knitr::opts_current$get("label"))
+      ) {
+    lab <- paste0("tab:", chunk_label)
   }
 
   lab
